/******************************************************************************/
/* TEKNISA                                                                    */
/******************************************************************************/
/*                                                                            */
/* NOME: GRAVA_LOGSOLICITA                                                    */
/*                                                                            */
/* DESCRIO:                                                                 */
/*   Grava log de solicitao                                                 */
/*                                                                            */
/* CRIAO:                                                                   */
/* 12/02/2004 - Luiz Otvio de Souza                                          */
/*                                                                            */
/******************************************************************************/

IF EXISTS(SELECT * FROM sysobjects O, sysusers U
          WHERE
            o.name = 'GRAVA_LOGSOLICITA'  and
            type = 'TR'                 and
            u.uid = o.uid               and
            u.name = USER)
  DROP TRIGGER GRAVA_LOGSOLICITA
  GO

CREATE TRIGGER GRAVA_LOGSOLICITA
ON SOLICITA
FOR INSERT, UPDATE, DELETE

AS

DECLARE @V_IDGRAVLOGSOL   VARCHAR(03);
DECLARE @V_DSRDMUSULSOL VARCHAR(50);
DECLARE @V_DSENDUSULSOL VARCHAR(50);
DECLARE @V_DSNMUSULSOL  VARCHAR(50);
DECLARE @V_DSMETUSULSOL VARCHAR(250);
DECLARE @V_CDOPERLSOL   VARCHAR(12);

/* Variveis do cursor */
DECLARE @V_IDCOMANDO      VARCHAR(1);
DECLARE @V_CDFILSOLI      VARCHAR(4);
DECLARE @V_CDFILLANCA     VARCHAR(4);
DECLARE @V_NRSOLICMP      VARCHAR(10);
DECLARE @V_DTSOLCMP       DATETIME;
DECLARE @V_IDTIPLAN       VARCHAR(1);
DECLARE @V_OLD_IDSOLEXTRA VARCHAR(1);
DECLARE @V_NEW_IDSOLEXTRA VARCHAR(1);
DECLARE @V_OLD_IDBAIXASOL VARCHAR(1);
DECLARE @V_NEW_IDBAIXASOL VARCHAR(1);

BEGIN

   DECLARE C_DADOS CURSOR FOR
     SELECT
       'D' IDCOMANDO,
       CDFILSOLI,
       CDFILLANCA,
       NRSOLICMP,
       DTSOLCMP,
       IDTIPLAN,
       IDSOLEXTRA,
       IDSOLEXTRA,
       IDBAIXASOL,
       IDBAIXASOL
     FROM
       DELETED
     WHERE
       0 = (SELECT COUNT(*) FROM INSERTED)

     UNION ALL

     SELECT
       'U' IDCOMANDO,
       INSERTED.CDFILSOLI,
       INSERTED.CDFILLANCA,
       INSERTED.NRSOLICMP,
       INSERTED.DTSOLCMP,
       INSERTED.IDTIPLAN,
       DELETED.IDSOLEXTRA,
       INSERTED.IDSOLEXTRA,
       DELETED.IDBAIXASOL,
       INSERTED.IDBAIXASOL
     FROM
       INSERTED,
       DELETED
     WHERE
       INSERTED.CDFILLANCA = DELETED.CDFILLANCA AND
       INSERTED.CDFILSOLI  = DELETED.CDFILSOLI  AND
       INSERTED.NRSOLICMP  = DELETED.NRSOLICMP

     UNION ALL

     SELECT
       'I' IDCOMANDO,
       CDFILSOLI,
       CDFILLANCA,
       NRSOLICMP,
       DTSOLCMP,
       IDTIPLAN,
       IDSOLEXTRA,
       IDSOLEXTRA,
       IDBAIXASOL,
       IDBAIXASOL
     FROM
       INSERTED
     WHERE
       0 = (SELECT COUNT(*) FROM DELETED);

   OPEN C_DADOS;
   FETCH NEXT FROM C_DADOS INTO @V_IDCOMANDO,
                                @V_CDFILSOLI,
                                @V_CDFILLANCA,
                                @V_NRSOLICMP,
                                @V_DTSOLCMP,
                                @V_IDTIPLAN,
                                @V_OLD_IDSOLEXTRA,
                                @V_NEW_IDSOLEXTRA,
                                @V_OLD_IDBAIXASOL,
                                @V_NEW_IDBAIXASOL;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      SET @V_IDGRAVLOGSOL = 'SSS';
      SELECT @V_IDGRAVLOGSOL = MAX(ISNULL(IDGRAVLOGSOL, 'SSS'))
      FROM PARASUPRI
      WHERE (CDFILIAL = (SELECT MAX(ISNULL(CDFILCENTCMP, CDFILIAL))
                         FROM FILIAL
                         WHERE (CDFILIAL = @V_CDFILSOLI)));

     /* SET @V_DSRDMUSULSOL = 'VIA BD';
      SET @V_DSENDUSULSOL = 'VIA BD';
      SET @V_DSNMUSULSOL  = 'VIA BD';
      SET @V_DSMETUSULSOL = 'VIA BD';
      SET @V_CDOPERLSOL   = 'VIA BD';
      SELECT @V_DSRDMUSULSOL = ISNULL(MAX(DSSERVERRDM),  'VIA BD'),
             @V_DSENDUSULSOL = ISNULL(MAX(DSREMOTEADDR), 'VIA BD'),
             @V_DSNMUSULSOL  = ISNULL(MAX(DSREMOTEHOST), 'VIA BD'),
             @V_DSMETUSULSOL = ISNULL(MAX(DSSERVMETHOD), 'VIA BD'),
             @V_CDOPERLSOL   = ISNULL(MAX(DSREMOTEOPER), 'VIA BD')
      FROM SQLWEBTUNNING
      WHERE NRAUDSID = @@SPID AND
            CONVERT(DATETIME, CONVERT(VARCHAR, DTSTARTDATE, 103))  =
                         (SELECT MAX(DTSTARTDATE)
                                  FROM SQLWEBTUNNING S
                                  WHERE S.NRAUDSID = @@SPID); */
          EXEC WEBTUNNING @P_DSREMOTEADDR = @V_DSENDUSULSOL OUTPUT,
                          @P_DSREMOTEHOST = @V_DSNMUSULSOL OUTPUT,
                          @P_DSSERVERRDM  = @V_DSRDMUSULSOL OUTPUT,
                          @P_DSSERVMETHOD = @V_DSMETUSULSOL OUTPUT,
                          @P_DSREMOTEOPER = @V_CDOPERLSOL OUTPUT;

      IF @V_IDCOMANDO = 'I' /* Inserting */ BEGIN

         IF SUBSTRING(@V_IDGRAVLOGSOL, 1, 1) = 'S' BEGIN

            INSERT INTO LOGSOLICITA
            (CDFILSOLLSOL, CDFILLANLSOL, NRSOLCMPLSOL, DTSOLCMPLSOL, IDTIPLANLSOL, IDOPERALSOL,
             IDSOLEXTRANT, IDSOLEXTRDEP, IDBAIXSOLANT, IDBAIXSOLDEP, DSRDMUSULSOL, DSENDUSULSOL,
             DSNMUSULSOL,  DSMETUSULSOL, CDOPERLSOL, DTOPERASOL)
            VALUES
            (@V_CDFILSOLI, @V_CDFILLANCA, @V_NRSOLICMP, @V_DTSOLCMP, @V_IDTIPLAN, 'I',
             NULL, @V_NEW_IDSOLEXTRA, NULL, @V_NEW_IDBAIXASOL, @V_DSRDMUSULSOL, @V_DSENDUSULSOL, @V_DSNMUSULSOL, @V_DSMETUSULSOL, @V_CDOPERLSOL, GETDATE());

         END;

      END;

      IF @V_IDCOMANDO = 'U' /* Updating */ BEGIN

         IF SUBSTRING(@V_IDGRAVLOGSOL, 2, 1) = 'S' BEGIN

            INSERT INTO LOGSOLICITA
            (CDFILSOLLSOL, CDFILLANLSOL, NRSOLCMPLSOL, DTSOLCMPLSOL, IDTIPLANLSOL, IDOPERALSOL,
             IDSOLEXTRANT, IDSOLEXTRDEP, IDBAIXSOLANT, IDBAIXSOLDEP, DSRDMUSULSOL, DSENDUSULSOL,
             DSNMUSULSOL,  DSMETUSULSOL, CDOPERLSOL, DTOPERASOL)
            VALUES
            (@V_CDFILSOLI, @V_CDFILLANCA, @V_NRSOLICMP, @V_DTSOLCMP, @V_IDTIPLAN, 'A',
             @V_OLD_IDSOLEXTRA, @V_NEW_IDSOLEXTRA, @V_OLD_IDBAIXASOL, @V_NEW_IDBAIXASOL, @V_DSRDMUSULSOL, @V_DSENDUSULSOL, @V_DSNMUSULSOL, @V_DSMETUSULSOL, @V_CDOPERLSOL, GETDATE());

         END;

      END;

      IF @V_IDCOMANDO = 'D' /* Deleting */ BEGIN

         IF SUBSTRING(@V_IDGRAVLOGSOL, 3, 1) = 'S' BEGIN

            INSERT INTO LOGSOLICITA
            (CDFILSOLLSOL, CDFILLANLSOL, NRSOLCMPLSOL, DTSOLCMPLSOL, IDTIPLANLSOL, IDOPERALSOL,
             IDSOLEXTRANT, IDSOLEXTRDEP, IDBAIXSOLANT, IDBAIXSOLDEP, DSRDMUSULSOL, DSENDUSULSOL,
             DSNMUSULSOL,  DSMETUSULSOL, CDOPERLSOL, DTOPERASOL)
            VALUES
            (@V_CDFILSOLI, @V_CDFILLANCA, @V_NRSOLICMP, @V_DTSOLCMP, @V_IDTIPLAN, 'E',
             @V_OLD_IDSOLEXTRA, @V_OLD_IDSOLEXTRA, @V_OLD_IDBAIXASOL, @V_OLD_IDBAIXASOL, @V_DSRDMUSULSOL, @V_DSENDUSULSOL, @V_DSNMUSULSOL, @V_DSMETUSULSOL, @V_CDOPERLSOL, GETDATE());

         END;

      END;

      FETCH NEXT FROM C_DADOS INTO @V_IDCOMANDO,
                                   @V_CDFILSOLI,
                                   @V_CDFILLANCA,
                                   @V_NRSOLICMP,
                                   @V_DTSOLCMP,
                                   @V_IDTIPLAN,
                                   @V_OLD_IDSOLEXTRA,
                                   @V_NEW_IDSOLEXTRA,
                                   @V_OLD_IDBAIXASOL,
                                   @V_NEW_IDBAIXASOL;

   END;

   CLOSE      C_DADOS;
   DEALLOCATE C_DADOS;

END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'GRAVA_LOGSOLICITA','5.05.004';
GO

