function ReportDecorator(eventAggregator, restEngine, templateManager, ZhLogger) {
    
    eventAggregator.subscribe('onContainerOpen', function () {
        try {
            var container = templateManager.container;
            validContainer(container);
            if (container.customReportsConfig) {
                var customReportsConfig = container.customReportsConfig;
                validCustomReportsConfig(customReportsConfig);
                var widget = selectWidget(container, customReportsConfig.widgetName);
                var containerName = container.name;
                
                var fieldToChangeData = selectField(widget, customReportsConfig.fieldName);
                
                buildData(containerName, fieldToChangeData);
                
                const eventExists = eventExistsByCode(fieldToChangeData.events, 'exportStrategyToRow');
        
                if (!eventExists) {
                    addExportStrategyEvent(fieldToChangeData);
                }
            }
            
        } catch (e) {
            ZhLogger.warning(e);
        }
    });
    
    function buildData(containerName, fieldToChangeData) {
        restEngine.post("lib#/lib_getDataReportField", {
            "requestType": "Row",
            "row": [containerName.substr(0, 6)]
        }).then(function (callback) {
            var data = callback.dataset.dataReport;
            
            var valueField = fieldToChangeData.valueField;
            var descriptionField = fieldToChangeData.descriptionField;
            var strategyField = fieldToChangeData.strategyField;
            var defaultValue = fieldToChangeData.defaultValue;
            
            data = data.map(function(reportElement) {
                var newElement = {};
                newElement[valueField] = reportElement.value;
                newElement[descriptionField] = reportElement.description;
                newElement[strategyField] = reportElement.strategy;
                
                return newElement;
            });
            
            if (!fieldToChangeData.dataSource.data || fieldToChangeData.dataSource.data.length == 0) {
                fieldToChangeData.dataSource.data = data;
            } else {
                fieldToChangeData.dataSource.data = fieldToChangeData.dataSource.data.concat(data);
            }
            
            fieldToChangeData.applyDefaultValue();
            
        }.bind(this), function(error) {
            if (error.data && error.data.error) {
                throw error.data.error;
            } else {
                throw 'Ocorreu um erro ao buscar a lista de relátorios da tela.';
            }
        });
    }
    
    function selectWidget(container, widgetName) {
        var widget = container.getWidget(widgetName);
        
        if (widget) {
            return widget;
        } else {
            throw "A widget informada não existe dentro desse container.";
        }
    }
    
    function selectField(widget, fieldName) {
        var field = widget.getField(fieldName);
        
        if (field) {
            if (field.dataSource) {
                return field;
            } else {
                throw "O field informado não contém a propriedade dataSource.";    
            }
        } else {
            throw "O field informado não existe na widget informada.";
        }
    }
    
    function validContainer(container) {
        if (!container) {
            throw "Container não existe.";
        }
    }
    
    function validCustomReportsConfig(config) {
        if (!config.widgetName) {
            throw 'A propriedade widgetName não existe dentro de customReportsConfig.';
        }
        
        if (!config.fieldName) {
            throw 'A propriedade fieldName não existe dentro de customReportsConfig.';
        }
    }
    
    function eventExistsByCode(events, searchedCode) {
        return events.filter(function(event){
            return event.code.indexOf(searchedCode) != -1;
        }).length > 0;
    }
    
    function addExportStrategyEvent(fieldToChangeData) {
        fieldToChangeData.events.push(
            {
                name: 'FieldOnChange',
                code: 'ReportDecorator.exportStrategyToRow(args.owner.field)'
            }
        );
    }

    this.exportStrategyToRow = function(field) {
        const reportCode = field.value();
        const report = field.dataSource.data.find(function(data){ 
            return data.REPORT == reportCode;
        });
        
        field.getParent().currentRow.STRATEGY = report.strategy;
    };
}
Configuration(function(ContextRegister){
    ContextRegister.register('ReportDecorator', ReportDecorator);
});